@@ -10,9 +10,9 @@ import numpy as np
 from PIL import Image
 
 from ultralytics.data.utils import IMG_FORMATS
-from ultralytics.utils import LOGGER
+from ultralytics.utils import LOGGER, TORCH_VERSION
 from ultralytics.utils.checks import check_requirements
-from ultralytics.utils.torch_utils import select_device
+from ultralytics.utils.torch_utils import TORCH_2_4, select_device
 
 os.environ["KMP_DUPLICATE_LIB_OK"] = "TRUE"  # Avoid OpenMP conflict on some systems
 
@@ -33,7 +33,7 @@ class VisualAISearch:
         data_dir (Path): Path object for the data directory.
         model: Loaded CLIP model.
         index: FAISS index for similarity search.
-        image_paths (List[str]): List of image file paths.
+        image_paths (list[str]): List of image file paths.
 
     Methods:
         extract_image_feature: Extract CLIP embedding from an image.
@@ -49,6 +49,7 @@ class VisualAISearch:
 
     def __init__(self, **kwargs: Any) -> None:
         """Initialize the VisualAISearch class with FAISS index and CLIP model."""
+        assert TORCH_2_4, f"VisualAISearch requires torch>=2.4 (found torch=={TORCH_VERSION})"
         from ultralytics.nn.text_model import build_text_model
 
         check_requirements("faiss-cpu")
@@ -138,7 +139,7 @@ class VisualAISearch:
             similarity_thresh (float, optional): Minimum similarity threshold for filtering results.
 
         Returns:
-            (List[str]): List of image filenames ranked by similarity score.
+            (list[str]): List of image filenames ranked by similarity score.
 
         Examples:
             Search for images matching a query
